import { Image as ExpoImage } from 'expo-image'
import React from 'react'
import { AccessibilityProps, Image as ReactNativeImage } from 'react-native'

import { transformSourcesURL } from '@holi/ui/components/atoms/HoliImage/resizing'
import { MobileImageProps } from '@holi/ui/components/atoms/HoliImage/types'

// left in here for future possibility of speed comparison
const debugWithReactNativeImage = false

// https://github.com/expo/expo/issues/21921 is fixed, so we can use expo-image again
const HoliImage = ({
  source,
  blurhash,
  label,
  style,
  resizeMode = 'cover',
  testID,
  onLayout,
  onError,
}: MobileImageProps) => {
  const accessibilityProps: AccessibilityProps = {
    accessible: !!label,
    role: 'img',
    accessibilityRole: 'image',
    'aria-label': label,
  }

  const transformedSource = transformSourcesURL(source)

  if (debugWithReactNativeImage && (resizeMode === 'cover' || resizeMode === 'contain' || resizeMode === undefined)) {
    // no blurhash available, only applicable to certain resize modes
    return (
      <ReactNativeImage
        source={transformedSource}
        style={style}
        resizeMode={resizeMode}
        testID={testID}
        onLayout={onLayout}
        {...accessibilityProps}
      />
    )
  }

  return (
    <ExpoImage
      source={transformedSource}
      placeholder={blurhash}
      style={style}
      contentFit={resizeMode}
      testID={testID}
      onError={onError}
      onLayout={onLayout}
      {...accessibilityProps}
    />
  )
}

export default HoliImage
